#!/usr/bin/python3

APP_ID = "org.gnome.World.Iotas"
GETTEXT_PACKAGE = "iotas"
LOCALEDIR = "/usr/share/locale"
NAME = "Iotas"
PKGDATADIR = "/usr/share/iotas"
PROFILE = ""
VERSION = "0.11.0"

IS_DEVEL = PROFILE == "Devel"
SUFFIX = " (Devel)" if IS_DEVEL else ""
SHORT_NAME = GETTEXT_PACKAGE

APP_ID_CHANGE_VERSION = "0.2.7"

# Mirroring libadwaita/src/stylesheet/widgets/_header-bar.scss:2:  min-height: 47px;
HEADER_BAR_HEIGHT = 47
